@@ -38,8 +38,10 @@ import warnings
 try:
     # Python 3
     from collections import UserList
-    from imp import reload
     UserList  # pyflakes
+    with warnings.catch_warnings():
+        warnings.simplefilter('ignore')
+        from imp import reload
 except ImportError:
     # Python 2 ships that in a different module
     from UserList import UserList
@@ -90,8 +92,8 @@ def enable():
     # gobject
     from gi.repository import GObject
     sys.modules['gobject'] = GObject
-    from gi._gobject import propertyhelper
-    sys.modules['gobject.propertyhelper'] = propertyhelper
+    from gi import _propertyhelper
+    sys.modules['gobject.propertyhelper'] = _propertyhelper
 
     # gio
     from gi.repository import Gio
@@ -139,7 +141,10 @@ def enable_gtk(version='3.0'):
     Gdk.PixbufLoader = GdkPixbuf.PixbufLoader.new_with_type
     Gdk.pixbuf_new_from_data = GdkPixbuf.Pixbuf.new_from_data
     Gdk.pixbuf_new_from_file = GdkPixbuf.Pixbuf.new_from_file
-    Gdk.pixbuf_new_from_file_at_scale = GdkPixbuf.Pixbuf.new_from_file_at_scale
+    try:
+        Gdk.pixbuf_new_from_file_at_scale = GdkPixbuf.Pixbuf.new_from_file_at_scale
+    except AttributeError:
+        pass
     Gdk.pixbuf_new_from_file_at_size = GdkPixbuf.Pixbuf.new_from_file_at_size
     Gdk.pixbuf_new_from_inline = GdkPixbuf.Pixbuf.new_from_inline
     Gdk.pixbuf_new_from_stream = GdkPixbuf.Pixbuf.new_from_stream
@@ -349,12 +354,15 @@ def enable_gtk(version='3.0'):
     Gtk.image_new_from_file = Gtk.Image.new_from_file
     Gtk.settings_get_default = Gtk.Settings.get_default
     Gtk.window_set_default_icon = Gtk.Window.set_default_icon
-    Gtk.clipboard_get = Gtk.Clipboard.get
+    try:
+        Gtk.clipboard_get = Gtk.Clipboard.get
+    except AttributeError:
+        pass
 
-    #AccelGroup
+    # AccelGroup
     Gtk.AccelGroup.connect_group = Gtk.AccelGroup.connect
 
-    #StatusIcon
+    # StatusIcon
     Gtk.status_icon_position_menu = Gtk.StatusIcon.position_menu
     Gtk.StatusIcon.set_tooltip = Gtk.StatusIcon.set_tooltip_text
 
