@@ -10,6 +10,11 @@ import warnings
 from gi.repository import GObject
 from gi.repository import GIMarshallingTests
 
+try:
+    from gi.repository import Regress
+except ImportError:
+    Regress = None
+
 
 class StrongRef(object):
     # A class that behaves like weakref.ref but holds a strong reference.
@@ -601,3 +606,33 @@ class TestPropertyHoldingObject(unittest.TestCase):
     def test_set_object_property_to_invalid_type(self):
         obj = GIMarshallingTests.PropertiesObject()
         self.assertRaises(TypeError, obj.set_property, 'some-object', 'not_an_object')
+
+
+@unittest.skipIf(Regress is None, 'Regress is required')
+class TestArgumentTypeErrors(unittest.TestCase):
+    def test_object_argument_type_error(self):
+        # ensure TypeError is raised for things which are not GObjects
+        obj = Regress.TestObj()
+        obj.set_bare(GObject.Object())
+        obj.set_bare(None)
+
+        self.assertRaises(TypeError, obj.set_bare, object())
+        self.assertRaises(TypeError, obj.set_bare, 42)
+        self.assertRaises(TypeError, obj.set_bare, 'not an object')
+
+    def test_instance_argument_error(self):
+        # ensure TypeError is raised for non Regress.TestObj instances.
+        obj = Regress.TestObj()
+        self.assertEqual(Regress.TestObj.instance_method(obj), -1)
+        self.assertRaises(TypeError, Regress.TestObj.instance_method, object())
+        self.assertRaises(TypeError, Regress.TestObj.instance_method, GObject.Object())
+        self.assertRaises(TypeError, Regress.TestObj.instance_method, 42)
+        self.assertRaises(TypeError, Regress.TestObj.instance_method, 'not an object')
+
+    def test_instance_argument_base_type_error(self):
+        # ensure TypeError is raised when a base type is passed to something
+        # expecting a derived type
+        obj = Regress.TestSubObj()
+        self.assertEqual(Regress.TestSubObj.instance_method(obj), 0)
+        self.assertRaises(TypeError, Regress.TestSubObj.instance_method, GObject.Object())
+        self.assertRaises(TypeError, Regress.TestSubObj.instance_method, Regress.TestObj())
